module VenueManagement
  class Engine < ::Rails::Engine
    initializer "venue_management" do
      OrbitApp.registration "VenueManagement", :type => "ModuleApp" do
        module_label "venue_management.venue_management"
        base_url File.expand_path File.dirname(__FILE__)
        authorizable
        categorizable
        taggable "VenueManagementInviting"
        frontend_enabled
        data_count 1..20

        side_bar do
          head_label_i18n 'venue_management.venue_management', icon_class: "icon-globe"
          available_for "sub_managers"
          active_for_controllers (['admin/venue_managements'])
          head_link_path "admin_venue_managements_path"

          context_link 'list_',
                                :link_path=>"admin_venue_managements_path" ,
                                :priority=>1,
                                :active_for_action=>{'admin/venue_managements'=>'index'},
                                :available_for => 'sub_managers'
          context_link 'new_',
                                :link_path=>"new_admin_venue_management_path" ,
                                :priority=>2,
                                :active_for_action=>{'admin/venue_managements'=>'new'},
                                :available_for => 'sub_managers'
          context_link 'categories',
                                :link_path=>"admin_module_app_categories_path" ,
                                :link_arg=>"{:module_app_id=>ModuleApp.find_by(:key=>'venue_management').id}",
                                :priority=>3,
                                :active_for_action=>{'admin/venue_managements'=>'categories'},
                                :active_for_category => 'VenueManagement',
                                :available_for => 'sub_managers'
          context_link 'tags',
                                :link_path=>"admin_module_app_tags_path" ,
                                :link_arg=>"{:module_app_id=>ModuleApp.find_by(:key=>'venue_management').id}",
                                :priority=>4,
                                :active_for_action=>{'admin/venue_managements'=>'tags'},
                                :active_for_tag => 'VenueManagement',
                                :available_for => 'sub_managers'
          context_link 'venue_management.set_venue_management_items',
                                :link_path=>"admin_venue_management_items_path" ,
                                :priority=>5,
                                :active_for_action=>{'admin/venue_managements'=>'venue_management_items'},
                                :available_for => 'sub_managers'
          context_link 'venue_management.set_venue_management_agreements',
                                :link_path=>"admin_venue_management_agreements_path" ,
                                :priority=>6,
                                :active_for_action=>{'admin/venue_managements'=>'venue_management_agreements'},
                                :available_for => 'sub_managers'
          context_link 'venue_management.set_venue_management_invitings',
                                :link_path => 'admin_venue_management_invitings_path',
                                :priority => 7,
                                :active_for_action => { 'admin/venue_managements' => 'venue_management_invitings' },
                                :available_for => 'sub_managers'
          context_link 'venue_management.set_venue_management_memorabilias',
                                :link_path => 'admin_venue_management_memorabilias_path',
                                :priority => 8,
                                :active_for_action => { 'admin/venue_managements' => 'venue_management_memorabilias' },
                                :available_for => 'sub_managers'
          context_link 'venue_management.set_venue_management_bills',
                                :link_path => 'admin_venue_management_bills_path',
                                :priority => 8,
                                :active_for_action => { 'admin/venue_managements' => 'venue_management_bills' },
                                :available_for => 'sub_managers'
          context_link 'venue_management.set_venue_management_contracts',
                                :link_path => 'admin_venue_management_contracts_path',
                                :priority => 9,
                                :active_for_action => { 'admin/venue_managements' => 'venue_management_contracts' },
                                :available_for => 'sub_managers'
        end
      end
    end
  end
end
